@@ -85,7 +85,22 @@ func (s *composeService) build(ctx context.Context, project *types.Project, opti
 		policy = types.IncludeDependencies
 	}
 
-	err := project.ForEachService(options.Services, func(serviceName string, service *types.ServiceConfig) error {
+	var err error
+	if len(options.Services) > 0 {
+		// As user requested some services to be built, also include those used as additional_contexts
+		options.Services = addBuildDependencies(options.Services, project)
+		// Some build dependencies we just introduced may not be enabled
+		project, err = project.WithServicesEnabled(options.Services...)
+		if err != nil {
+			return nil, err
+		}
+	}
+	project, err = project.WithSelectedServices(options.Services)
+	if err != nil {
+		return nil, err
+	}
+
+	err = project.ForEachService(options.Services, func(serviceName string, service *types.ServiceConfig) error {
 		if service.Build == nil {
 			return nil
 		}
@@ -466,6 +481,11 @@ func (s *composeService) toBuildOptions(project *types.Project, service types.Se
 		return build.Options{}, err
 	}
 
+	attests := map[string]*string{}
+	if !options.Provenance {
+		attests["provenance"] = nil
+	}
+
 	return build.Options{
 		Inputs: build.Inputs{
 			ContextPath:      service.Build.Context,
@@ -489,6 +509,7 @@ func (s *composeService) toBuildOptions(project *types.Project, service types.Se
 		Session:      sessionConfig,
 		Allow:        allow,
 		SourcePolicy: sp,
+		Attests:      attests,
 	}, nil
 }
 
@@ -613,3 +634,21 @@ func parsePlatforms(service types.ServiceConfig) ([]specs.Platform, error) {
 
 	return ret, nil
 }
+
+func addBuildDependencies(services []string, project *types.Project) []string {
+	servicesWithDependencies := utils.NewSet(services...)
+	for _, service := range services {
+		b := project.Services[service].Build
+		if b != nil {
+			for _, target := range b.AdditionalContexts {
+				if s, found := strings.CutPrefix(target, types.ServicePrefix); found {
+					servicesWithDependencies.Add(s)
+				}
+			}
+		}
+	}
+	if len(servicesWithDependencies) > len(services) {
+		return addBuildDependencies(servicesWithDependencies.Elements(), project)
+	}
+	return servicesWithDependencies.Elements()
+}
