@@ -22,16 +22,13 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"io/fs"
 	"os"
 	"path/filepath"
-	"sort"
 	"strconv"
 	"strings"
 
+	"github.com/compose-spec/compose-go/v2/paths"
 	"github.com/compose-spec/compose-go/v2/types"
-	"github.com/docker/compose/v2/internal/desktop"
-	pathutil "github.com/docker/compose/v2/internal/paths"
 	"github.com/docker/compose/v2/pkg/api"
 	"github.com/docker/compose/v2/pkg/progress"
 	"github.com/docker/compose/v2/pkg/prompt"
@@ -155,61 +152,10 @@ func (s *composeService) ensureProjectVolumes(ctx context.Context, project *type
 		ids[k] = id
 	}
 
-	err := func() error {
-		if s.manageDesktopFileSharesEnabled(ctx) {
-			// collect all the bind mount paths and try to set up file shares in
-			// Docker Desktop for them
-			var paths []string
-			for _, svcName := range project.ServiceNames() {
-				svc := project.Services[svcName]
-				for _, vol := range svc.Volumes {
-					if vol.Type != string(mount.TypeBind) {
-						continue
-					}
-					p := filepath.Clean(vol.Source)
-					if !filepath.IsAbs(p) {
-						return fmt.Errorf("file share path is not absolute: %s", p)
-					}
-					if fi, err := os.Stat(p); errors.Is(err, fs.ErrNotExist) {
-						// actual directory will be implicitly created when the
-						// file share is initialized if it doesn't exist, so
-						// need to filter out any that should not be auto-created
-						if vol.Bind != nil && !vol.Bind.CreateHostPath {
-							logrus.Debugf("Skipping creating file share for %q: does not exist and `create_host_path` is false", p)
-							continue
-						}
-					} else if err != nil {
-						// if we can't read the path, we won't be able to make
-						// a file share for it
-						logrus.Debugf("Skipping creating file share for %q: %v", p, err)
-						continue
-					} else if !fi.IsDir() {
-						// ignore files & special types (e.g. Unix sockets)
-						logrus.Debugf("Skipping creating file share for %q: not a directory", p)
-						continue
-					}
-
-					paths = append(paths, p)
-				}
-			}
-
-			// remove duplicate/unnecessary child paths and sort them for predictability
-			paths = pathutil.EncompassingPaths(paths)
-			sort.Strings(paths)
-
-			fileShareManager := desktop.NewFileShareManager(s.desktopCli, project.Name, paths)
-			if err := fileShareManager.EnsureExists(ctx); err != nil {
-				return fmt.Errorf("initializing file shares: %w", err)
-			}
-		}
-		return nil
-	}()
-	if err != nil {
-		progress.ContextWriter(ctx).TailMsgf("Failed to prepare Synchronized file shares: %v", err)
-	}
 	return ids, nil
 }
 
+//nolint:gocyclo
 func (s *composeService) getCreateConfigs(ctx context.Context,
 	p *types.Project,
 	service types.ServiceConfig,
@@ -302,7 +248,10 @@ func (s *composeService) getCreateConfigs(ctx context.Context,
 	if err != nil {
 		return createConfigs{}, err
 	}
-	networkMode, networkingConfig := defaultNetworkSettings(p, service, number, links, opts.UseNetworkAliases, apiVersion)
+	networkMode, networkingConfig, err := defaultNetworkSettings(p, service, number, links, opts.UseNetworkAliases, apiVersion)
+	if err != nil {
+		return createConfigs{}, err
+	}
 	portBindings := buildContainerPortBindingOptions(service)
 
 	// MISC
@@ -412,7 +361,7 @@ func (s *composeService) prepareContainerMACAddress(ctx context.Context, service
 		}
 
 		if len(withMacAddress) > 1 {
-			return "", fmt.Errorf("a MAC address is specified for multiple networks (%s), but this feature requires Docker Engine 1.44 or later (currently: %s)", strings.Join(withMacAddress, ", "), version)
+			return "", fmt.Errorf("a MAC address is specified for multiple networks (%s), but this feature requires Docker Engine v25 or later", strings.Join(withMacAddress, ", "))
 		}
 
 		if mainNw != nil && mainNw.MacAddress != "" {
@@ -435,6 +384,8 @@ func getAliases(project *types.Project, service types.ServiceConfig, serviceInde
 }
 
 func createEndpointSettings(p *types.Project, service types.ServiceConfig, serviceIndex int, networkKey string, links []string, useNetworkAliases bool) *network.EndpointSettings {
+	const ifname = "com.docker.network.endpoint.ifname"
+
 	config := service.Networks[networkKey]
 	var ipam *network.EndpointIPAMConfig
 	var (
@@ -454,6 +405,15 @@ func createEndpointSettings(p *types.Project, service types.ServiceConfig, servi
 		}
 		macAddress = config.MacAddress
 		driverOpts = config.DriverOpts
+		if config.InterfaceName != "" {
+			if driverOpts == nil {
+				driverOpts = map[string]string{}
+			}
+			if name, ok := driverOpts[ifname]; ok && name != config.InterfaceName {
+				logrus.Warnf("ignoring services.%s.networks.%s.interface_name as %s driver_opts is already declared", service.Name, networkKey, ifname)
+			}
+			driverOpts[ifname] = config.InterfaceName
+		}
 		gwPriority = config.GatewayPriority
 	}
 	return &network.EndpointSettings{
@@ -527,20 +487,17 @@ func (s *composeService) prepareLabels(labels types.Labels, service types.Servic
 }
 
 // defaultNetworkSettings determines the container.NetworkMode and corresponding network.NetworkingConfig (nil if not applicable).
-func defaultNetworkSettings(
-	project *types.Project,
-	service types.ServiceConfig,
-	serviceIndex int,
-	links []string,
-	useNetworkAliases bool,
+func defaultNetworkSettings(project *types.Project,
+	service types.ServiceConfig, serviceIndex int,
+	links []string, useNetworkAliases bool,
 	version string,
-) (container.NetworkMode, *network.NetworkingConfig) {
+) (container.NetworkMode, *network.NetworkingConfig, error) {
 	if service.NetworkMode != "" {
-		return container.NetworkMode(service.NetworkMode), nil
+		return container.NetworkMode(service.NetworkMode), nil, nil
 	}
 
 	if len(project.Networks) == 0 {
-		return "none", nil
+		return "none", nil, nil
 	}
 
 	var primaryNetworkKey string
@@ -571,6 +528,14 @@ func defaultNetworkSettings(
 		}
 	}
 
+	if versions.LessThan(version, "1.49") {
+		for _, config := range service.Networks {
+			if config != nil && config.InterfaceName != "" {
+				return "", nil, fmt.Errorf("interface_name requires Docker Engine v28.1 or later")
+			}
+		}
+	}
+
 	endpointsConfig[primaryNetworkMobyNetworkName] = primaryNetworkEndpoint
 	networkConfig := &network.NetworkingConfig{
 		EndpointsConfig: endpointsConfig,
@@ -579,7 +544,7 @@ func defaultNetworkSettings(
 	// From the Engine API docs:
 	// > Supported standard values are: bridge, host, none, and container:<name|id>.
 	// > Any other value is taken as a custom network's name to which this container should connect to.
-	return container.NetworkMode(primaryNetworkMobyNetworkName), networkConfig
+	return container.NetworkMode(primaryNetworkMobyNetworkName), networkConfig, nil
 }
 
 func getRestartPolicy(service types.ServiceConfig) container.RestartPolicy {
@@ -1162,28 +1127,22 @@ func isUnixAbs(p string) bool {
 }
 
 func isWindowsAbs(p string) bool {
-	if strings.HasPrefix(p, "\\\\") {
-		return true
-	}
-	if len(p) > 2 && p[1] == ':' {
-		return p[2] == '\\'
-	}
-	return false
+	return paths.IsWindowsAbs(p)
 }
 
 func buildMount(project types.Project, volume types.ServiceVolumeConfig) (mount.Mount, error) {
 	source := volume.Source
-	// on windows, filepath.IsAbs(source) is false for unix style abs path like /var/run/docker.sock.
-	// do not replace these with  filepath.Abs(source) that will include a default drive.
-	if volume.Type == types.VolumeTypeBind && !filepath.IsAbs(source) && !strings.HasPrefix(source, "/") {
-		// volume source has already been prefixed with workdir if required, by compose-go project loader
-		var err error
-		source, err = filepath.Abs(source)
-		if err != nil {
-			return mount.Mount{}, err
+	switch volume.Type {
+	case types.VolumeTypeBind:
+		if !filepath.IsAbs(source) && !isUnixAbs(source) && !isWindowsAbs(source) {
+			// volume source has already been prefixed with workdir if required, by compose-go project loader
+			var err error
+			source, err = filepath.Abs(source)
+			if err != nil {
+				return mount.Mount{}, err
+			}
 		}
-	}
-	if volume.Type == types.VolumeTypeVolume {
+	case types.VolumeTypeVolume:
 		if volume.Source != "" {
 			pVolume, ok := project.Volumes[volume.Source]
 			if ok {
